lock.py — Rucio 0.3.8 documentation

# lock.py

`GET` `/locks`

  get locks for a given rse.

  Example request:

      GET /locks HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type: 'application/x-json-stream'

  Status Codes: | 500 Internal Server Error – e.__class__.__name__: e.args[0]

`GET` `/locks`

  get locks for a given scope, name.

  Example request:

      GET /locks HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type: 'application/x-json-stream'

  Status Codes: | 500 Internal Server Error – e.__class__.__name__: e.args[0]